<?php
/**
 * Kids Education options
 *
 * @package Theme Palace
 * @subpackage Kids Education Pro
 * @since Kids Education Pro 1.0
 */

/**
 * Returns list of typography
 * @return array font styles
 */
function kids_education_pro_typography_options(){

    $choices = array(
      'poppins-courgette' => esc_html__( 'POPPINS AND COURGETTE FONT', 'kids-education-pro' ),
      'roboto-monsterrat' => esc_html__( 'ROBOTO AND MONTSERRAT FONT', 'kids-education-pro' ),
      'raleway-poppins'   => esc_html__( 'RALEWAY AND POPPINS FONT', 'kids-education-pro' ),
      'courgette-roboto'  => esc_html__( 'COURGETTE AND ROBOTO FONT', 'kids-education-pro' ),
      'default'           => esc_html__( 'DEFAULT', 'kids-education-pro' ),
      'pacifico'          => esc_html__( 'PACIFICO FONT', 'kids-education-pro' ),
      'indie-flower'      => esc_html__( 'INDIE FLOWER FONT', 'kids-education-pro' ),
      'atma'              => esc_html__( 'ATMA FONT', 'kids-education-pro' )
    );
    $output = apply_filters( 'kids_education_pro_typography_options', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

}

/**
 * Site Layout
 * @return array site layout options
 */
function kids_education_pro_site_layout() {
  $kids_education_pro_site_layout = array(
    'wide'  => esc_html__( 'Wide', 'kids-education-pro' ),
    'boxed' => esc_html__( 'Boxed', 'kids-education-pro' ),
  );

  $output = apply_filters( 'kids_education_pro_site_layout', $kids_education_pro_site_layout );

  return $output;
}

/**
 * Sidebar position
 * @return array Sidbar positions
 */
function kids_education_pro_sidebar_position() {
  $kids_education_pro_sidebar_position = array(
    'right-sidebar' => esc_html__( 'Right', 'kids-education-pro' ),
    'left-sidebar'  => esc_html__( 'Left', 'kids-education-pro' ),
    'no-sidebar'    => esc_html__( 'No Sidebar', 'kids-education-pro' ),
  );

  $output = apply_filters( 'kids_education_pro_sidebar_position', $kids_education_pro_sidebar_position );

  return $output;
}

/**
 * Site Design
 * @return array site design options
 */
function kids_education_pro_site_design() {
  $kids_education_pro_site_design = array(
    'classic-design'  => esc_html__( 'Classic Design', 'kids-education-pro' ),
    'modern-design'   => esc_html__( 'Modern Design', 'kids-education-pro' ),
  );

  $output = apply_filters( 'kids_education_pro_site_design', $kids_education_pro_site_design );

  return $output;
}

/**
 * Header image options
 * @return array Header image options
 */
function kids_education_pro_header_image() {
  $kids_education_pro_header_image = array(
    'enable' => esc_html__( 'Enable( Featured Image )', 'kids-education-pro' ),
    '' => esc_html__( 'Default ( Customizer Header Image )', 'kids-education-pro' ),
    'disable'  => esc_html__( 'Disable', 'kids-education-pro' ),
  );

  $output = apply_filters( 'kids_education_pro_header_image', $kids_education_pro_header_image );

  return $output;
}

/**
 * Pagination
 * @return array site pagination options
 */
function kids_education_pro_pagination_options() {
  $kids_education_pro_pagination_options = array(
    'numeric'         => esc_html__( 'Numeric', 'kids-education-pro' ),
    'default'         => esc_html__( 'Default(Older/Newer)', 'kids-education-pro' ),
    'infinite-scroll' => esc_html__( 'Infinite-Scroll', 'kids-education-pro' ),
    'infinite-click'  => esc_html__( 'Infinite-Click', 'kids-education-pro' ),
  );

  $output = apply_filters( 'kids_education_pro_pagination_options', $kids_education_pro_pagination_options );

  return $output;
}

/**
 * Slider
 * @return array slider options
 */
function kids_education_pro_enable_disable_options() {
  $kids_education_pro_enable_disable_options = array(
    'static-frontpage'  => esc_html__( 'Static Frontpage', 'kids-education-pro' ),
    'disabled'          => esc_html__( 'Disabled', 'kids-education-pro' ),
  );

  $output = apply_filters( 'kids_education_pro_enable_disable_options', $kids_education_pro_enable_disable_options );

  return $output;
}

/**
 * Slider effects
 * @return array Slider effects
 */
function kids_education_pro_slider_effect() {
  $kids_education_pro_slider_effect = array(
    'cubic-bezier(0.680, 0, 0.265, 1)'            => esc_html__( 'Default', 'kids-education-pro' ),
    'fade'                                        => esc_html__( 'Fade', 'kids-education-pro' ),
    'cubic-bezier(0.250, 0.250, 0.750, 0.750)'    => esc_html__( 'Linear', 'kids-education-pro' ),
    'cubic-bezier(0.250, 0.100, 0.250, 1.000)'    => esc_html__( 'Ease', 'kids-education-pro' ),
    'cubic-bezier(0.950, 0.050, 0.795, 0.035)'    => esc_html__( 'cubic', 'kids-education-pro' ),
    'cubic-bezier(0.600, -0.280, 0.735, 0.045)'   => esc_html__( 'Ease In Back', 'kids-education-pro' ),
    'cubic-bezier(0.785, 0.135, 0.150, 0.860)'    => esc_html__( 'EaseInOutCirc', 'kids-education-pro' ),
    'cubic-bezier(0.680, -0.550, 0.265, 1.550)'   => esc_html__( 'EaseInOutBack', 'kids-education-pro' ),
  );

  $output =  apply_filters( 'kids_education_pro_slider_effect', $kids_education_pro_slider_effect );

  // Sort array in ascending order, according to the key:
  if ( ! empty( $output ) ) {
    ksort( $output );
  }

  return $output;
}

/**
 * Returns list for recent section content type
 * @return array content type
 */
function kids_education_pro_recent_content_type(){

    $choices        = array(
      'demo'        => esc_html__( 'Demo', 'kids-education-pro' ),
      'post'        => esc_html__( 'Post', 'kids-education-pro' ),
    );
    $custom_choices = array();
    if ( class_exists( 'TP_Education' ) ) {
      $custom_choices = array(
        'class'       => esc_html__( 'Class', 'kids-education-pro' ),
        'course'      => esc_html__( 'Course', 'kids-education-pro' ),
        'event'       => esc_html__( 'Event', 'kids-education-pro' ),
        'excursion'   => esc_html__( 'Excursion', 'kids-education-pro' ),
      );
    }
    $choices = array_merge( $choices, $custom_choices );
    $output = apply_filters( 'kids_education_pro_recent_content_type', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

}

/**
 * Returns list for testimonial section content type
 * @return array content type
 */
function kids_education_pro_testimonial_content_type(){

    $choices        = array(
      'demo'        => esc_html__( 'Demo', 'kids-education-pro' ),
    );
    $custom_choices = array();
    if ( class_exists( 'TP_Education' ) ) {
      $custom_choices = array(
        'post'       => esc_html__( 'Testimonial Posts', 'kids-education-pro' ),
      );
    }
    $choices = array_merge( $choices, $custom_choices );
    $output = apply_filters( 'kids_education_pro_recent_content_type', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

}

/**
 * Returns list for team section content type
 * @return array content type
 */
function kids_education_pro_team_content_type(){

    $choices        = array(
      'demo'        => esc_html__( 'Demo', 'kids-education-pro' ),
    );
    $custom_choices = array();
    if ( class_exists( 'TP_Education' ) ) {
      $custom_choices = array(
        'post'       => esc_html__( 'Team Posts', 'kids-education-pro' ),
        'category'   => esc_html__( 'Team Category', 'kids-education-pro' ),
      );
    }
    $choices = array_merge( $choices, $custom_choices );
    $output = apply_filters( 'kids_education_pro_recent_content_type', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

}